smartcard.ReaderMonitoring.ReaderMonitor

# ``smartcard`.`ReaderMonitoring`.`ReaderMonitor``

class documentation

`class ReaderMonitor(Observable):`

View In Hierarchy

Class that monitors reader insertion/removal. and notify observers

note: a reader monitoring thread will be running as long as the reader monitor has observers, or ReaderMonitor.stop() is called.

It implements the shared state design pattern, where objects of the same type all share the same state, in our case essentially the ReaderMonitoring Thread. Thanks to Frank Aune for implementing the shared state pattern logics.

Method | `__init__` | Undocumented
Method | `__str__` | Undocumented
Method | `addObserver` | Add an observer.
Method | `deleteObserver` | Remove an observer.
Instance Variable | `__dict__` | Undocumented
Instance Variable | `period` | Undocumented
Instance Variable | `readerProc` | Undocumented
Instance Variable | `rmthread` | Undocumented
Instance Variable | `startOnDemand` | Undocumented
Class Variable | `__shared_state` | Undocumented

Inherited from `Observable`:

Method | `clearChanged` | Undocumented
Method | `countObservers` | Undocumented
Method | `deleteObservers` | Undocumented
Method | `hasChanged` | Undocumented
Method | `notifyObservers` | If 'changed' indicates that this object has changed, notify all its observers, then call clearChanged(). Each observer has its update() called with two arguments: this observable object and the generic 'arg'.
Method | `setChanged` | Undocumented
Instance Variable | `changed` | Undocumented
Instance Variable | `obs` | Undocumented

Inherited from `Synchronization` (via `Observable`):

Instance Variable | `mutex` | Undocumented

def __init__(self, startOnDemand=True, readerProc=smartcard.System.readers, period=1):
overrides `smartcard.Observer.Observable.__init__`

Undocumented

def __str__(self):

Undocumented

def addObserver(self, observer):
overrides `smartcard.Observer.Observable.addObserver`

Add an observer.

def deleteObserver(self, observer):
overrides `smartcard.Observer.Observable.deleteObserver`

Remove an observer.

__dict__ =

Undocumented

period =

Undocumented

readerProc =

Undocumented

rmthread =

Undocumented

startOnDemand =

Undocumented

__shared_state: `dict` =

Undocumented